#include <Wire.h>

#include "stdint.h"

#define MAX_I2C_TXRX 2

//Platform dependent I2C function
void i2c_transfer(uint8_t *tx, uint8_t *rx, uint8_t txlen, uint8_t rxlen) {
  Wire.beginTransmission(0xF0 >> 1);  // Get the slave's attention, tell it we're sending a command byte
  for (int i = 0; i < txlen; i++) {
    Wire.write(tx[i]);  //  The command byte, sets pointer to register with address of 0x32
  }
  // End the transmission and check if it was successful
  if (Wire.endTransmission() != 0) {
    // Handle error if needed
    return;
  }

  Wire.requestFrom(0xF0 >> 1, (int)rxlen);  // Tell slave we need to read 1byte from the current register
  for (int i = 0; i < rxlen; i++) {
    byte slaveByte2 = Wire.read();  // read that byte into 'slaveByte2' variable
    rx[i] = slaveByte2;
  }
}

void touchpad_i2c_read(uint8_t addr, uint8_t *value, uint8_t readlen) {
  uint8_t addr_1 = addr | 0x80;  //for read operation
  i2c_transfer(&addr_1, value, 1, readlen);
}

void touchpad_i2c_write(uint8_t addr, uint8_t value) {
  uint8_t tx_data[2];
  tx_data[0] = addr;
  tx_data[1] = value;
  i2c_transfer(tx_data, 0, 2, 0);
}

//static void read_param()

//channel values from 1 to 12
int touchpad_read_channel_state(int channel) {
  uint8_t state;
  touchpad_i2c_read(0x11 + channel - 1, &state, 1);
  return state;
}

int touchpad_get_gain(int channel) {
  uint8_t gain;
  touchpad_i2c_read(0x31 + channel - 1, &gain, 1);
  return gain;
}

void touchpad_set_gain(int channel, uint8_t gain) {
  touchpad_i2c_write(channel, gain);
}


void setup() {
  Wire.begin();  // join i2c bus with address #8
  // Wire.onRequest(requestEvent); // register event
  Serial.begin(9600);
}

void loop() {
  for (int i = 1; i <= 12; i++) {
    int state = touchpad_read_channel_state(i);
    if (state==1) {
      Serial.print(i);
      Serial.println();
    }else if (state==255){
      Serial.print("Not Connected");
    }
    delay(10);
  }
}